import useMessagesStore from "@/feature/messenger/store/chat_store/useMessagesStore";
import { Tabs, Tab, Card, CardBody, Chip } from "@nextui-org/react";
import BabgeFile from "./BabgeFile";
import useHandleConversationStore from "@/feature/messenger/store/useHandleConversationStore";
import { X } from "react-feather";
import { useTranslation } from "@/hooks/useTranslation";

interface ListCategoryFileConversation {
    listCategoryPhotos?: any[];
    listCategoryFiles?: any[];
    listCategoryLink?: any[];
}

export default function FileSection() {
    const listCategoryFileConversation: ListCategoryFileConversation = useMessagesStore((state) => state.listCategoryFileConversation);
    const listCategoryPhotos = listCategoryFileConversation?.listCategoryPhotos || [];
    const listCategoryFiles = listCategoryFileConversation?.listCategoryFiles || [];
    const listCategoryLink = listCategoryFileConversation?.listCategoryLink || [];
    const openFileShareConversation = useHandleConversationStore((state) => state.openFileShareConversation);
    const handleOpenFileShareConversation = useHandleConversationStore((state) => state.actions.handleOpenFileShareConversation);
    const { trans } = useTranslation();


    return (
        <div className={`${openFileShareConversation ? 'block' : 'hidden'} absolute top-0 right-0 w-full lg:w-[40%] h-full z-10 bg-white/70 backdrop-blur-md shadow-2xl duration-100 rounded-xl`}>
            <div className="w-full h-full overflow-y-auto overflow-x-hidden">
                <div className="flex justify-between items-start p-4">
                    <div>
                        <p className="text-lg font-semibold">{trans('content_chat_sidebar_resources_title')}</p>
                        <p>{trans('content_chat_sidebar_resources_subtitle')}</p>
                    </div>
                    <div>
                        <X className="cursor-pointer" onClick={() => handleOpenFileShareConversation()} />
                    </div>
                </div>
                <div className="max-h-full">
                    <Tabs color="secondary" aria-label="Options" className="max-h-full w-full flex justify-center items-center">
                        <Tab key="fotos" title={trans('content_chat_sidebar_resources_tab_one_title')}>
                            <Card>
                                <CardBody>
                                    <div className="grid grid-cols-2 gap-1" >
                                        {listCategoryPhotos.map((image: any, index) => (

                                            <div key={index}>
                                                <a href={image} target="_blank">
                                                    <img className="h-auto max-w-full rounded-lg" src={image} alt="" width={"150"} />
                                                </a>
                                            </div>

                                        ))}
                                    </div>
                                    {listCategoryPhotos.length === 0 && (
                                        <div className="flex justify-center items-center w-full">
                                            <Chip color="warning" variant="bordered">
                                                {trans('content_chat_sidebar_resources_tab_one_empty_title')}
                                            </Chip>
                                        </div>
                                    )}
                                </CardBody>
                            </Card>
                        </Tab>
                        <Tab key="archivos" title={trans('content_chat_sidebar_resources_tab_two_title')}>
                            <Card>
                                <CardBody className="overflow-y-auto overflow-x-hidden max-h-">
                                    <div className="flex flex-col justify-center items-center w-full gap-2">
                                        {listCategoryFiles.map((item: any, index) => (
                                            <BabgeFile key={index} href={item.url} />
                                        ))}
                                    </div>

                                    {listCategoryFiles.length === 0 && (
                                        <div className="flex justify-center items-center w-full">
                                            <Chip color="warning" variant="bordered">
                                                {trans('content_chat_sidebar_resources_tab_two_empty_title')}
                                            </Chip>
                                        </div>
                                    )}
                                </CardBody>
                            </Card>
                        </Tab>
                        <Tab key="link" title={trans('content_chat_sidebar_resources_tab_three_title')}>
                            <Card>
                                <CardBody>
                                    <div className="flex flex-col justify-center items-center w-full gap-2">
                                        {listCategoryLink.map((item: any, index) => (
                                            <div className="flex justify-center items-center w-full" key={index}>
                                                <a className="w-full border-1 border-b-indigo-600" href={item.url} target="_blank">
                                                    {item.name}
                                                </a>
                                            </div>
                                        ))}
                                    </div>
                                    {listCategoryLink.length === 0 && (
                                        <div className="flex justify-center items-center w-full">
                                            <Chip color="warning" variant="bordered">
                                                {trans('content_chat_sidebar_resources_tab_three_empty_title')}
                                            </Chip>
                                        </div>
                                    )}
                                </CardBody>
                            </Card>
                        </Tab>
                    </Tabs>
                </div>
            </div>
        </div>
    )
}